===========
CompChemJob
===========


.. image:: https://img.shields.io/pypi/v/ccjob.svg
        :target: https://pypi.python.org/pypi/ccjob

.. image:: https://img.shields.io/travis/spectre007/ccjob.svg
        :target: https://travis-ci.com/spectre007/ccjob

.. image:: https://readthedocs.org/projects/ccjob/badge/?version=latest
        :target: https://ccjob.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Easy automation for quantum chemistry jobs.


* Free software: MIT license


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
